import { OpenAPIV2 } from 'openapi-types';
export interface SchemaInterface {
    type?: string;
    format?: string;
    ref?: string;
    allOf?: SchemaInterface[];
    items?: SchemaInterface;
    properties?: {
        [name: string]: SchemaInterface;
    };
    getType?(): string | undefined;
    getFormat?(): string | undefined;
    getItems?(): SchemaInterface;
    getReference?(): string | undefined;
    getAllOf?(): SchemaInterface[];
}
export declare class Schema implements SchemaInterface {
    type?: string;
    format?: string;
    ref?: string;
    allOf?: SchemaInterface[];
    items?: SchemaInterface;
    properties?: {
        [name: string]: SchemaInterface;
    };
    /**
     * constructor
     *
     * @param {Object} [schema=null]
     */
    constructor(schema?: Partial<OpenAPIV2.SchemaObject>);
    /**
     * @param {{ [name: string]: OpenAPIV2.SchemaObject}} properties
     * @return {*}  {Schema}
     * @memberof Schema
     */
    setProperties(properties: {
        [name: string]: OpenAPIV2.SchemaObject;
    }): Schema;
    /**
     * @param {String} type
     */
    setType(type: string | string[]): Schema;
    /**
     * @param {Array<Object>} allOf
     */
    setAllOf(allOf: any): this;
    /**
     * @param {String} format
     */
    setFormat(format: string): Schema;
    /**
     * @param {Object} items
     */
    setItems(items: any): this;
    /**
     * @param {String} ref
     */
    setReference(ref: string): Schema;
    /**
     * @return {String}
     */
    getType(): string | undefined;
    /**
     * @return {String}
     */
    getFormat(): string | undefined;
    /**
     * @return {Object}
     */
    getItems(): SchemaInterface;
    /**
     * @return {String}
     */
    getReference(): string | undefined;
    /**
     * @return {Array<Schema>}
     */
    getAllOf(): SchemaInterface[];
    getProperties(): {
        [name: string]: SchemaInterface;
    };
}
