"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.transformInfo = void 0;
const contact_1 = require("./contact");
const license_1 = require("./license");
const markdown_1 = require("../../lib/markdown");
/**
 * http://swagger.io/specification/#infoObject
 * Prepare page header
 * Leave description with no changes
 * @param {Object} info
 * @returns {String}
 */
function transformInfo(info) {
    const md = markdown_1.Markdown.md();
    if (info !== null && typeof info === 'object') {
        if ('title' in info) {
            md.line(md.string(info.title).h1());
        }
        if ('description' in info) {
            md.line(md.string(info.description).escape()).line();
        }
        if ('version' in info) {
            md.line(md.string(`Version: ${info.version}`).h2()).line();
        }
        if ('termsOfService' in info) {
            md.line(md.string('Terms of service').h3())
                .line(md.string(info.termsOfService).escape())
                .line();
        }
        if ('contact' in info && Object.keys(info.contact).length) {
            md.line((0, contact_1.transformContact)(info.contact));
        }
        if ('license' in info && Object.keys(info.contact).length) {
            md.line((0, license_1.transformLicense)(info.license));
        }
    }
    return md.length ? md.export() : null;
}
exports.transformInfo = transformInfo;
